@@ -16,16 +16,21 @@
 """Identity v3 federation mapping action implementations"""
 
 import json
+import logging
 
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
 import six
 
-from openstackclient.common import command
-from openstackclient.common import exceptions
-from openstackclient.common import utils
+from openstackclient.i18n import _
+
+
+LOG = logging.getLogger(__name__)
 
 
 class _RulesReader(object):
-    """Helper class capable of reading rules from files"""
+    _description = _("Helper class capable of reading rules from files")
 
     def _read_rules(self, path):
         """Read and parse rules from path
@@ -69,27 +74,27 @@ class _RulesReader(object):
         try:
             rules = json.loads(blob)
         except ValueError as e:
-            raise exceptions.CommandError(
-                'An error occurred when reading '
-                'rules from file %s: %s' % (path, e))
+            msg = _("An error occurred when reading rules from file "
+                    "%(path)s: %(error)s") % {"path": path, "error": e}
+            raise exceptions.CommandError(msg)
         else:
             return rules
 
 
 class CreateMapping(command.ShowOne, _RulesReader):
-    """Create new mapping"""
+    _description = _("Create new mapping")
 
     def get_parser(self, prog_name):
         parser = super(CreateMapping, self).get_parser(prog_name)
         parser.add_argument(
             'mapping',
             metavar='<name>',
-            help='New mapping name (must be unique)',
+            help=_('New mapping name (must be unique)'),
         )
         parser.add_argument(
             '--rules',
             metavar='<filename>', required=True,
-            help='Filename that contains a set of mapping rules (required)',
+            help=_('Filename that contains a set of mapping rules (required)'),
         )
         return parser
 
@@ -106,25 +111,39 @@ class CreateMapping(command.ShowOne, _RulesReader):
 
 
 class DeleteMapping(command.Command):
-    """Delete mapping"""
+    _description = _("Delete mapping(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteMapping, self).get_parser(prog_name)
         parser.add_argument(
             'mapping',
             metavar='<mapping>',
-            help='Mapping to delete',
+            nargs='+',
+            help=_('Mapping(s) to delete'),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
+        result = 0
+        for i in parsed_args.mapping:
+            try:
+                identity_client.federation.mappings.delete(i)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete mapping with name or "
+                          "ID '%(mapping)s': %(e)s")
+                          % {'mapping': i, 'e': e})
 
-        identity_client.federation.mappings.delete(parsed_args.mapping)
+        if result > 0:
+            total = len(parsed_args.mapping)
+            msg = (_("%(result)s of %(total)s mappings failed "
+                   "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListMapping(command.Lister):
-    """List mappings"""
+    _description = _("List mappings")
 
     def take_action(self, parsed_args):
         # NOTE(marek-denis): Since rules can be long and tedious I have decided
@@ -138,29 +157,25 @@ class ListMapping(command.Lister):
 
 
 class SetMapping(command.Command, _RulesReader):
-    """Set mapping properties"""
+    _description = _("Set mapping properties")
 
     def get_parser(self, prog_name):
         parser = super(SetMapping, self).get_parser(prog_name)
         parser.add_argument(
             'mapping',
             metavar='<name>',
-            help='Mapping to modify',
+            help=_('Mapping to modify'),
         )
         parser.add_argument(
             '--rules',
             metavar='<filename>',
-            help='Filename that contains a new set of mapping rules',
+            help=_('Filename that contains a new set of mapping rules'),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        if not parsed_args.rules:
-            self.app.log.error("No changes requested")
-            return
-
         rules = self._read_rules(parsed_args.rules)
 
         mapping = identity_client.federation.mappings.update(
@@ -172,14 +187,14 @@ class SetMapping(command.Command, _RulesReader):
 
 
 class ShowMapping(command.ShowOne):
-    """Display mapping details"""
+    _description = _("Display mapping details")
 
     def get_parser(self, prog_name):
         parser = super(ShowMapping, self).get_parser(prog_name)
         parser.add_argument(
             'mapping',
             metavar='<mapping>',
-            help='Mapping to display',
+            help=_('Mapping to display'),
         )
         return parser
 
